<img width="300px" src="https://sickrage.ca/img/logo-stacked.png" />

# 

##Mon Jul 13 2020 01:18:20 GMT+0000 (Coordinated Universal Time)


## Bug Fixes
  - Fixed issues with app shutdown and restarts Refactored Tornado IOLoop integration
  ([1325174c](https://gitlab-ci-token:oB8JzdTgjeJKzfyESYxp@git.sickrage.ca/SiCKRAGE/sickrage/commit/1325174caa77fcc0443b24cec7223301029dd128))




